@@ -37,6 +37,9 @@ class Sequence():
 
     def __getitem__(self, key):
         return self.value[key]
+    
+    def __len__(self):
+        return len(self.value)
 
     def __add__(self, other: Union['Sequence', Symbol]) -> 'Sequence':
         if isinstance(other, Sequence):
